Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration class
Constructors
-
Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration({required List<
Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration$alarmConfigurations> alarmConfigurations, String $__typename = 'PlusDevice'}) -
Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
alarmConfigurations
→ List<
Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration$alarmConfigurations> -
final
-
copyWith
→ CopyWith$Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration<
Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration> -
Available on Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration, provided by the UtilityExtension$Mutation$AddOrUpdateEnergyUsageLimitAlarm$addOrUpdatePlusDeviceEnergyUsageLimitAlarmConfiguration extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override