CopyWith$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration<TRes> class
abstract
Constructors
- CopyWith$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration(Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration instance, TRes then(Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration))
-
factory
- CopyWith$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alarmConfigurations(
Iterable< Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations> _fn(Iterable<CopyWith$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations< )) → TResMutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations> > -
call(
{List< Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations> ? alarmConfigurations, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited