Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration class
Constructors
-
Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration({required List<
Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations> alarmConfigurations, String $__typename = 'PlusDevice'}) -
Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
alarmConfigurations
→ List<
Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration$alarmConfigurations> -
final
-
copyWith
→ CopyWith$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration<
Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration> -
Available on Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration, provided by the UtilityExtension$Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override