Mutation$AddOrUpdateLowPowerAlarm class

Available extensions

Constructors

Mutation$AddOrUpdateLowPowerAlarm({Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration? addOrUpdatePlusDeviceLowPowerAlarmConfiguration, String $__typename = 'Mutation'})
Mutation$AddOrUpdateLowPowerAlarm.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
addOrUpdatePlusDeviceLowPowerAlarmConfiguration Mutation$AddOrUpdateLowPowerAlarm$addOrUpdatePlusDeviceLowPowerAlarmConfiguration?
final
copyWith CopyWith$Mutation$AddOrUpdateLowPowerAlarm<Mutation$AddOrUpdateLowPowerAlarm>

Available on Mutation$AddOrUpdateLowPowerAlarm, provided by the UtilityExtension$Mutation$AddOrUpdateLowPowerAlarm extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override