CopyWith$Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration<TRes> class
abstract
Constructors
- CopyWith$Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration(Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration instance, TRes then(Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration))
-
factory
- CopyWith$Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alarmConfigurations(
Iterable< Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration$alarmConfigurations> _fn(Iterable<CopyWith$Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration$alarmConfigurations< )) → TResMutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration$alarmConfigurations> > -
call(
{List< Mutation$AddOrUpdateOfflineAlarm$addOrUpdatePlusDeviceOfflineAlarmConfiguration$alarmConfigurations> ? alarmConfigurations, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited