Mutation$UnpairDeviceWithExternalId class

Available extensions

Constructors

Mutation$UnpairDeviceWithExternalId({required Mutation$UnpairDeviceWithExternalId$unpairDeviceWithExternalId unpairDeviceWithExternalId, String $__typename = 'Mutation'})
Mutation$UnpairDeviceWithExternalId.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Mutation$UnpairDeviceWithExternalId<Mutation$UnpairDeviceWithExternalId>

Available on Mutation$UnpairDeviceWithExternalId, provided by the UtilityExtension$Mutation$UnpairDeviceWithExternalId extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unpairDeviceWithExternalId Mutation$UnpairDeviceWithExternalId$unpairDeviceWithExternalId
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override