CopyWith$Mutation$UpdateDeviceAliasV2<TRes> class
abstract
Constructors
- CopyWith$Mutation$UpdateDeviceAliasV2(Mutation$UpdateDeviceAliasV2 instance, TRes then(Mutation$UpdateDeviceAliasV2))
-
factory
- CopyWith$Mutation$UpdateDeviceAliasV2.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updateDeviceAliasV2
→ CopyWith$Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2<
TRes> -
no setter
Methods
-
call(
{Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2? updateDeviceAliasV2, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited