Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2 class
- Available extensions
Constructors
- Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2({required String id, String? alias, String $__typename = 'Device'})
-
Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- alias → String?
-
final
-
copyWith
→ CopyWith$Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2<
Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2> -
Available on Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2, provided by the UtilityExtension$Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2 extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override