Mutation$UpdateDeviceAliasV2 class

Available extensions

Constructors

Mutation$UpdateDeviceAliasV2({Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2? updateDeviceAliasV2, String $__typename = 'Mutation'})
Mutation$UpdateDeviceAliasV2.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Mutation$UpdateDeviceAliasV2<Mutation$UpdateDeviceAliasV2>

Available on Mutation$UpdateDeviceAliasV2, provided by the UtilityExtension$Mutation$UpdateDeviceAliasV2 extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateDeviceAliasV2 Mutation$UpdateDeviceAliasV2$updateDeviceAliasV2?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override