Mutation$UpdateDeviceLocalMQTTV2 class
- Available extensions
Constructors
- Mutation$UpdateDeviceLocalMQTTV2({Mutation$UpdateDeviceLocalMQTTV2$updateDeviceLocalMQTTV2? updateDeviceLocalMQTTV2, String $__typename = 'Mutation'})
-
Mutation$UpdateDeviceLocalMQTTV2.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
copyWith
→ CopyWith$Mutation$UpdateDeviceLocalMQTTV2<
Mutation$UpdateDeviceLocalMQTTV2> -
Available on Mutation$UpdateDeviceLocalMQTTV2, provided by the UtilityExtension$Mutation$UpdateDeviceLocalMQTTV2 extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateDeviceLocalMQTTV2 → Mutation$UpdateDeviceLocalMQTTV2$updateDeviceLocalMQTTV2?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override