Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2 class
Constructors
- Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2({required String id, String $__typename = 'Device'})
-
Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
copyWith
→ CopyWith$Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2<
Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2> -
Available on Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2, provided by the UtilityExtension$Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2 extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override