Mutation$UpdateRmsCurrentMaxPerPhaseV2 class

Available extensions

Properties

$__typename String
final
copyWith CopyWith$Mutation$UpdateRmsCurrentMaxPerPhaseV2<Mutation$UpdateRmsCurrentMaxPerPhaseV2>

Available on Mutation$UpdateRmsCurrentMaxPerPhaseV2, provided by the UtilityExtension$Mutation$UpdateRmsCurrentMaxPerPhaseV2 extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateRmsCurrentMaxPerPhaseAmpereV2 Mutation$UpdateRmsCurrentMaxPerPhaseV2$updateRmsCurrentMaxPerPhaseAmpereV2?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override