CopyWith$Query$GetAlarmConfigurations$deviceByIdV2$plusDevice$alarmConfigurations$$PlusDeviceFuseOverloadAlarmConfiguration<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({int? criticalThresholdPercent, int? warningThresholdPercent, Enum$AlarmTriggerMode? triggerMode, int? criticalDatapoints, int? criticalDurationSeconds, int? warningDatapoints, int? warningDurationSeconds, String? $__typename, String? id, bool? isEnabled, DateTime? createdOnUtc, DateTime? updatedOnUtc}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited