CopyWith$Query$GetAlarmConfigurations$deviceByIdV2$plusDevice<TRes> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alarmConfigurations(
Iterable< Query$GetAlarmConfigurations$deviceByIdV2$plusDevice$alarmConfigurations> _fn(Iterable<CopyWith$Query$GetAlarmConfigurations$deviceByIdV2$plusDevice$alarmConfigurations< )) → TResQuery$GetAlarmConfigurations$deviceByIdV2$plusDevice$alarmConfigurations> > -
call(
{List< Query$GetAlarmConfigurations$deviceByIdV2$plusDevice$alarmConfigurations> ? alarmConfigurations, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited