CopyWith$Query$GetDeviceByIdV2$deviceByIdV2$plusDevice<TRes> class abstract

Properties

deviceType CopyWith$Query$GetDeviceByIdV2$deviceByIdV2$plusDevice$deviceType<TRes>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({String? mepKey, String? opticalKey, String? gpk60Key, String? gpk61Key, bool? localMqttEnabled, String? localMqttBroker, int? localMqttPort, String? localMqttUser, String? localMqttPassword, int? blinksPerKwh, double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, String? errorCode, bool? isOnline, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Query$GetDeviceByIdV2$deviceByIdV2$plusDevice$deviceType? deviceType, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited