Query$GetDeviceByIdV2$deviceByIdV2$plusDevice class

Available extensions

Constructors

Query$GetDeviceByIdV2$deviceByIdV2$plusDevice({String? mepKey, String? opticalKey, String? gpk60Key, String? gpk61Key, bool? localMqttEnabled, String? localMqttBroker, int? localMqttPort, String? localMqttUser, String? localMqttPassword, int? blinksPerKwh, double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, String? errorCode, required bool isOnline, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Query$GetDeviceByIdV2$deviceByIdV2$plusDevice$deviceType? deviceType, String $__typename = 'PlusDevice'})
Query$GetDeviceByIdV2$deviceByIdV2$plusDevice.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
allTimesHighConsumption double?
final
allTimesHighProduction double?
final
blinksPerKwh int?
final
consumptionAlarmMaxWh int?
final
copyWith CopyWith$Query$GetDeviceByIdV2$deviceByIdV2$plusDevice<Query$GetDeviceByIdV2$deviceByIdV2$plusDevice>

Available on Query$GetDeviceByIdV2$deviceByIdV2$plusDevice, provided by the UtilityExtension$Query$GetDeviceByIdV2$deviceByIdV2$plusDevice extension

no setter
deviceType Query$GetDeviceByIdV2$deviceByIdV2$plusDevice$deviceType?
final
errorCode String?
final
gpk60Key String?
final
gpk61Key String?
final
hashCode int
The hash code for this object.
no setteroverride
hasProduction bool?
final
isOnline bool
final
localMqttBroker String?
final
localMqttEnabled bool?
final
localMqttPassword String?
final
localMqttPort int?
final
localMqttUser String?
final
mepKey String?
final
opticalKey String?
final
rmsCurrentMaxPerPhaseAmpere double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override