Query$GetDeviceByIdV2$deviceByIdV2 class

Available extensions

Constructors

Query$GetDeviceByIdV2$deviceByIdV2({required String id, required String serial, String? devicePop, String? alias, Query$GetDeviceByIdV2$deviceByIdV2$plusDevice? plusDevice, String $__typename = 'Device'})
Query$GetDeviceByIdV2$deviceByIdV2.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
alias String?
final
copyWith CopyWith$Query$GetDeviceByIdV2$deviceByIdV2<Query$GetDeviceByIdV2$deviceByIdV2>

Available on Query$GetDeviceByIdV2$deviceByIdV2, provided by the UtilityExtension$Query$GetDeviceByIdV2$deviceByIdV2 extension

no setter
devicePop String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
plusDevice Query$GetDeviceByIdV2$deviceByIdV2$plusDevice?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override