Query$GetDeviceByIdV2 class

Available extensions

Constructors

Query$GetDeviceByIdV2({Query$GetDeviceByIdV2$deviceByIdV2? deviceByIdV2, String $__typename = 'Query'})
Query$GetDeviceByIdV2.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Query$GetDeviceByIdV2<Query$GetDeviceByIdV2>

Available on Query$GetDeviceByIdV2, provided by the UtilityExtension$Query$GetDeviceByIdV2 extension

no setter
deviceByIdV2 Query$GetDeviceByIdV2$deviceByIdV2?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override