CopyWith$Fragment$MyDevice$plusDevice<TRes> class abstract

Properties

baseDevice CopyWith$Fragment$MyDevice$plusDevice$baseDevice<TRes>
no setter
deviceType CopyWith$Fragment$MyDevice$plusDevice$deviceType<TRes>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, int? blinksPerKwh, String? errorCode, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Fragment$MyDevice$plusDevice$deviceType? deviceType, List<Fragment$MyDevice$plusDevice$remoteDevices>? remoteDevices, Fragment$MyDevice$plusDevice$baseDevice? baseDevice, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remoteDevices(Iterable<Fragment$MyDevice$plusDevice$remoteDevices>? _fn(Iterable<CopyWith$Fragment$MyDevice$plusDevice$remoteDevices<Fragment$MyDevice$plusDevice$remoteDevices>>?)) → TRes
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited