CopyWith$Fragment$MyDevice<TRes> class abstract

Constructors

CopyWith$Fragment$MyDevice(Fragment$MyDevice instance, TRes then(Fragment$MyDevice))
factory
CopyWith$Fragment$MyDevice.stub(TRes res)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
plusDevice CopyWith$Fragment$MyDevice$plusDevice<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({String? id, String? alias, String? serial, Fragment$MyDevice$plusDevice? plusDevice, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited