CopyWith$Query$GetMyDevices$pairedDevices$plusDevice<TRes> class abstract

Properties

baseDevice CopyWith$Query$GetMyDevices$pairedDevices$plusDevice$baseDevice<TRes>
no setter
deviceType CopyWith$Query$GetMyDevices$pairedDevices$plusDevice$deviceType<TRes>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, int? blinksPerKwh, String? errorCode, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Query$GetMyDevices$pairedDevices$plusDevice$deviceType? deviceType, List<Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices>? remoteDevices, Query$GetMyDevices$pairedDevices$plusDevice$baseDevice? baseDevice, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remoteDevices(Iterable<Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices>? _fn(Iterable<CopyWith$Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices<Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices>>?)) → TRes
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited