Fragment$MyDevice class

Implementers
Available extensions

Constructors

Fragment$MyDevice({required String id, String? alias, required String serial, Fragment$MyDevice$plusDevice? plusDevice, String $__typename = 'Device'})
Fragment$MyDevice.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
alias String?
final
copyWith CopyWith$Fragment$MyDevice<Fragment$MyDevice>

Available on Fragment$MyDevice, provided by the UtilityExtension$Fragment$MyDevice extension

no setter
hashCode int
The hash code for this object.
no setteroverride
id String
final
plusDevice Fragment$MyDevice$plusDevice?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override