Query$GetMyDevices$pairedDevices$plusDevice class
- Implemented types
- Available extensions
Constructors
-
Query$GetMyDevices$pairedDevices$plusDevice({double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, int? blinksPerKwh, String? errorCode, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Query$GetMyDevices$pairedDevices$plusDevice$deviceType? deviceType, List<
Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices> ? remoteDevices, Query$GetMyDevices$pairedDevices$plusDevice$baseDevice? baseDevice, String $__typename = 'PlusDevice'}) -
Query$GetMyDevices$pairedDevices$plusDevice.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- allTimesHighConsumption → double?
-
final
- allTimesHighProduction → double?
-
final
- baseDevice → Query$GetMyDevices$pairedDevices$plusDevice$baseDevice?
-
final
- blinksPerKwh → int?
-
final
- consumptionAlarmMaxWh → int?
-
final
-
copyWith
→ CopyWith$Fragment$MyDevice$plusDevice<
Fragment$MyDevice$plusDevice> -
Available on Fragment$MyDevice$plusDevice, provided by the UtilityExtension$Fragment$MyDevice$plusDevice extension
no setter -
copyWith
→ CopyWith$Query$GetMyDevices$pairedDevices$plusDevice<
Query$GetMyDevices$pairedDevices$plusDevice> -
Available on Query$GetMyDevices$pairedDevices$plusDevice, provided by the UtilityExtension$Query$GetMyDevices$pairedDevices$plusDevice extension
no setter - deviceType → Query$GetMyDevices$pairedDevices$plusDevice$deviceType?
-
final
- errorCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasProduction → bool?
-
final
-
remoteDevices
→ List<
Query$GetMyDevices$pairedDevices$plusDevice$remoteDevices> ? -
final
- rmsCurrentMaxPerPhaseAmpere → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override