Query$GetMyDevices$pairedDevices class
- Implemented types
- Available extensions
Constructors
- Query$GetMyDevices$pairedDevices({required String id, String? alias, required String serial, Query$GetMyDevices$pairedDevices$plusDevice? plusDevice, String $__typename = 'Device'})
-
Query$GetMyDevices$pairedDevices.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- alias → String?
-
final
-
copyWith
→ CopyWith$Fragment$MyDevice<
Fragment$MyDevice> -
Available on Fragment$MyDevice, provided by the UtilityExtension$Fragment$MyDevice extension
no setter -
copyWith
→ CopyWith$Query$GetMyDevices$pairedDevices<
Query$GetMyDevices$pairedDevices> -
Available on Query$GetMyDevices$pairedDevices, provided by the UtilityExtension$Query$GetMyDevices$pairedDevices extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- plusDevice → Query$GetMyDevices$pairedDevices$plusDevice?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serial → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override