CopyWith$Fragment$PlusDeviceOnboardingSession<TRes> class
abstract
Constructors
- CopyWith$Fragment$PlusDeviceOnboardingSession(Fragment$PlusDeviceOnboardingSession instance, TRes then(Fragment$PlusDeviceOnboardingSession))
-
factory
- CopyWith$Fragment$PlusDeviceOnboardingSession.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{int? id, DateTime? lastUpdatedOn, DateTime? startedOn, Enum$PlusDeviceOnboardingSessionStatus? status, DateTime? completedOn, String? errorCode, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited