CopyWith$Query$IsHealthy<TRes> class abstract

Constructors

CopyWith$Query$IsHealthy(Query$IsHealthy instance, TRes then(Query$IsHealthy))
factory
CopyWith$Query$IsHealthy.stub(TRes res)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isHealthy CopyWith$Query$IsHealthy$isHealthy<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({Query$IsHealthy$isHealthy? isHealthy, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited