Query$IsHealthy class

Available extensions

Constructors

Query$IsHealthy({required Query$IsHealthy$isHealthy isHealthy, String $__typename = 'Query'})
Query$IsHealthy.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Query$IsHealthy<Query$IsHealthy>

Available on Query$IsHealthy, provided by the UtilityExtension$Query$IsHealthy extension

no setter
hashCode int
The hash code for this object.
no setteroverride
isHealthy Query$IsHealthy$isHealthy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override