CopyWith$Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({String? deviceId, int? warningThresholdPercent, int? criticalThresholdPercent, Enum$AlarmTriggerMode? triggerMode, int? warningDatapoints, int? warningDurationSeconds, int? criticalDatapoints, int? criticalDurationSeconds, bool? isEnabled}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited