CopyWith$Input$UpdateDeviceEncryptionKeysFromInputsInput<TRes> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? deviceId, List< Input$EncryptionInputForMutationInput> ? encryptionInputs}) → TRes -
encryptionInputs(
Iterable< Input$EncryptionInputForMutationInput> _fn(Iterable<CopyWith$Input$EncryptionInputForMutationInput< )) → TResInput$EncryptionInputForMutationInput> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited