Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput class

Constructors

Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput({required String deviceId, required int warningThresholdPercent, required int criticalThresholdPercent, required Enum$AlarmTriggerMode triggerMode, int? warningDatapoints, int? warningDurationSeconds, int? criticalDatapoints, int? criticalDurationSeconds, required bool isEnabled})
factory
Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput<Input$AddOrUpdatePlusDeviceFuseOverloadAlarmConfigurationInput>
no setter
criticalDatapoints int?
no setter
criticalDurationSeconds int?
no setter
criticalThresholdPercent int
no setter
deviceId String
no setter
hashCode int
The hash code for this object.
no setteroverride
isEnabled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerMode Enum$AlarmTriggerMode
no setter
warningDatapoints int?
no setter
warningDurationSeconds int?
no setter
warningThresholdPercent int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override