Input$AddOrUpdatePlusDeviceLowPowerAlarmConfigurationInput class

Constructors

Input$AddOrUpdatePlusDeviceLowPowerAlarmConfigurationInput({required String deviceId, required int consumptionThresholdW, required Enum$AlarmTriggerMode triggerMode, int? datapoints, int? durationSeconds, required bool isEnabled})
factory
Input$AddOrUpdatePlusDeviceLowPowerAlarmConfigurationInput.fromJson(Map<String, dynamic> data)
factory

Properties

consumptionThresholdW int
no setter
copyWith CopyWith$Input$AddOrUpdatePlusDeviceLowPowerAlarmConfigurationInput<Input$AddOrUpdatePlusDeviceLowPowerAlarmConfigurationInput>
no setter
datapoints int?
no setter
deviceId String
no setter
durationSeconds int?
no setter
hashCode int
The hash code for this object.
no setteroverride
isEnabled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerMode Enum$AlarmTriggerMode
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override