Input$AddOrUpdatePlusDeviceOfflineAlarmConfigurationInput class

Constructors

Input$AddOrUpdatePlusDeviceOfflineAlarmConfigurationInput({required String deviceId, required int offlineThresholdSeconds, required bool isEnabled})
factory
Input$AddOrUpdatePlusDeviceOfflineAlarmConfigurationInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$AddOrUpdatePlusDeviceOfflineAlarmConfigurationInput<Input$AddOrUpdatePlusDeviceOfflineAlarmConfigurationInput>
no setter
deviceId String
no setter
hashCode int
The hash code for this object.
no setteroverride
isEnabled bool
no setter
offlineThresholdSeconds int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override