Input$UpdateDeviceEncryptionKeysFromInputsInput class
Constructors
-
Input$UpdateDeviceEncryptionKeysFromInputsInput({required String deviceId, required List<
Input$EncryptionInputForMutationInput> encryptionInputs}) -
factory
-
Input$UpdateDeviceEncryptionKeysFromInputsInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
copyWith
→ CopyWith$Input$UpdateDeviceEncryptionKeysFromInputsInput<
Input$UpdateDeviceEncryptionKeysFromInputsInput> -
no setter
- deviceId → String
-
no setter
-
encryptionInputs
→ List<
Input$EncryptionInputForMutationInput> -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override