Fragment$MyDevice$plusDevice class
- Implementers
- Available extensions
Constructors
-
Fragment$MyDevice$plusDevice({double? allTimesHighConsumption, double? allTimesHighProduction, bool? hasProduction, int? blinksPerKwh, String? errorCode, double? rmsCurrentMaxPerPhaseAmpere, int? consumptionAlarmMaxWh, Fragment$MyDevice$plusDevice$deviceType? deviceType, List<
Fragment$MyDevice$plusDevice$remoteDevices> ? remoteDevices, Fragment$MyDevice$plusDevice$baseDevice? baseDevice, String $__typename = 'PlusDevice'}) -
Fragment$MyDevice$plusDevice.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- allTimesHighConsumption → double?
-
final
- allTimesHighProduction → double?
-
final
- baseDevice → Fragment$MyDevice$plusDevice$baseDevice?
-
final
- blinksPerKwh → int?
-
final
- consumptionAlarmMaxWh → int?
-
final
-
copyWith
→ CopyWith$Fragment$MyDevice$plusDevice<
Fragment$MyDevice$plusDevice> -
Available on Fragment$MyDevice$plusDevice, provided by the UtilityExtension$Fragment$MyDevice$plusDevice extension
no setter - deviceType → Fragment$MyDevice$plusDevice$deviceType?
-
final
- errorCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasProduction → bool?
-
final
-
remoteDevices
→ List<
Fragment$MyDevice$plusDevice$remoteDevices> ? -
final
- rmsCurrentMaxPerPhaseAmpere → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override