Fragment$PlusDeviceOnboardingSession class
- Available extensions
Constructors
- Fragment$PlusDeviceOnboardingSession({required int id, required DateTime lastUpdatedOn, required DateTime startedOn, required Enum$PlusDeviceOnboardingSessionStatus status, DateTime? completedOn, String? errorCode, String $__typename = 'PlusDeviceOnboardingSession'})
-
Fragment$PlusDeviceOnboardingSession.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- completedOn → DateTime?
-
final
-
copyWith
→ CopyWith$Fragment$PlusDeviceOnboardingSession<
Fragment$PlusDeviceOnboardingSession> -
Available on Fragment$PlusDeviceOnboardingSession, provided by the UtilityExtension$Fragment$PlusDeviceOnboardingSession extension
no setter - errorCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- lastUpdatedOn → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedOn → DateTime
-
final
- status → Enum$PlusDeviceOnboardingSessionStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override