Enum$AlarmDeliveryStatus enum
Values
- DELIVERED → const Enum$AlarmDeliveryStatus
- FAILED → const Enum$AlarmDeliveryStatus
- IGNORED_DISABLED_ALARM_CONFIGURATION → const Enum$AlarmDeliveryStatus
- IGNORED_NO_PARTNER_WEBHOOK_INTEGRATION → const Enum$AlarmDeliveryStatus
- INTERNAL_ERROR_ON_PUBLISH_TO_PARTNER → const Enum$AlarmDeliveryStatus
- IGNORED_BY_PARTNER_WEBHOOK_INTEGRATION → const Enum$AlarmDeliveryStatus
- TIMEOUT → const Enum$AlarmDeliveryStatus
- $unknown → const Enum$AlarmDeliveryStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Enum$AlarmDeliveryStatus> - A constant List of the values in this enum, in order of their declaration.